

.. _sphx_glr_auto_examples_applications:

.. _realword_examples:

Examples based on real world datasets
-------------------------------------

Examples which use real-word dataset.



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Some balancing methods allow for balancing dataset with multiples classes. We provide an exampl...">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_plot_multi_class_under_sampling_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_plot_multi_class_under_sampling.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Multiclass classification with under-sampling</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to balance the text data before to train a classifier.">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_plot_topic_classication_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_plot_topic_classication.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Example of topic classification in text documents</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates the use of a custom sampler to implement an outlier rejections estimat...">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_plot_outlier_rejections_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_plot_outlier_rejections.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Customized sampler to implement an outlier rejections estimator</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this face recognition example two faces are used from the LFW (Faces in the Wild) dataset. S...">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_plot_over_sampling_benchmark_lfw_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_plot_over_sampling_benchmark_lfw.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Benchmark over-sampling methods in a face recognition task</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example compares two strategies to train a neural-network on the Porto Seguro Kaggle data ...">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_porto_seguro_keras_under_sampling_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_porto_seguro_keras_under_sampling.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Porto Seguro: balancing samples in mini-batches with Keras</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates the problem induced by learning on datasets having imbalanced classes....">

.. only:: html

  .. image:: /auto_examples/applications/images/thumb/sphx_glr_plot_impact_imbalanced_classes_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_applications_plot_impact_imbalanced_classes.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Fitting model on imbalanced datasets and how to fight bias</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/applications/plot_multi_class_under_sampling
   /auto_examples/applications/plot_topic_classication
   /auto_examples/applications/plot_outlier_rejections
   /auto_examples/applications/plot_over_sampling_benchmark_lfw
   /auto_examples/applications/porto_seguro_keras_under_sampling
   /auto_examples/applications/plot_impact_imbalanced_classes

